@@ -6,5 +6,5 @@ assert not all([False])
 assert all([])
 assert not all([False, TestFailingBool()])
 
-assert_raises(RuntimeError, lambda: all(TestFailingIter()))
-assert_raises(RuntimeError, lambda: all([TestFailingBool()]))
+assert_raises(RuntimeError, all, TestFailingIter())
+assert_raises(RuntimeError, all, [TestFailingBool()])
