@@ -1,3 +1,5 @@
+from testutils import assert_raises
+
 
 __name__ = "function"
 
@@ -72,3 +74,24 @@ def f6():
 
 
 f6()
+
+
+def f7():
+    try:
+        def t() -> void: # noqa: F821
+            pass
+    except NameError:
+        return True
+    return False
+
+assert f7()
+
+
+def f8() -> int:
+    return 10
+
+assert f8() == 10
+
+
+with assert_raises(SyntaxError):
+    exec('print(keyword=10, 20)')
