@@ -1,4 +1,4 @@
-from testutils import assertRaises
+from testutils import assert_raises
 
 class A(dict):
     def a():
@@ -9,7 +9,7 @@ class A(dict):
 
 
 assert A.__dict__['a'] == A.a
-with assertRaises(KeyError) as cm:
+with assert_raises(KeyError) as cm:
     A.__dict__['not here']
 
 assert cm.exception.args[0] == "not here"
