@@ -7,6 +7,10 @@ myobj = MyObject()
 assert myobj == myobj
 assert not myobj != myobj
 
+object.__subclasshook__() == NotImplemented
+object.__subclasshook__(1) == NotImplemented
+object.__subclasshook__(1, 2) == NotImplemented
+
 assert MyObject().__eq__(MyObject()) == NotImplemented
 assert MyObject().__ne__(MyObject()) == NotImplemented
 assert MyObject().__lt__(MyObject()) == NotImplemented
