@@ -1,4 +1,4 @@
-from testutils import assertRaises
+from testutils import assert_raises
 
 
 class Fubar:
@@ -53,13 +53,17 @@ p = property(lambda x: x[0])
 assert p.__get__((2,), tuple) == 2
 assert p.__get__((2,)) == 2
 
-with assertRaises(AttributeError):
+with assert_raises(AttributeError):
     null_property.__get__((), tuple)
 
-with assertRaises(TypeError):
+with assert_raises(TypeError):
     property.__new__(object)
 
-# assert p.__doc__ is None
+assert p.__doc__ is None
+
+# Test property instance __doc__ attribute:
+p.__doc__ = '222'
+assert p.__doc__ == '222'
 
 
 p1 = property("a", "b", "c")
