@@ -38,3 +38,12 @@ assert (foo,) == (foo,)
 a = (1, 2, 3)
 a += 1,
 assert a == (1, 2, 3, 1)
+
+b = (55, *a)
+assert b == (55, 1, 2, 3, 1)
+
+assert () is ()
+
+a = ()
+b = ()
+assert a is b
